@@ -3,7 +3,6 @@ package nodefeaturediscovery
 import (
 	"errors"
 
-	secv1 "github.com/openshift/api/security/v1"
 	nfdv1alpha1 "github.com/openshift/cluster-nfd-operator/pkg/apis/nfd/v1alpha1"
 )
 
@@ -38,9 +37,6 @@ func (n *NFD) init(r *ReconcileNodeFeatureDiscovery,
 	n.ins = i
 	n.idx = 0
 
-	secv1.AddToScheme(r.scheme)
-
-	addState(n, "/opt/nfd/config")
 	addState(n, "/opt/nfd/master")
 	addState(n, "/opt/nfd/worker")
 
